@@ -20,7 +20,7 @@
 
 #include "sageextensions.h"
 #include <QStringList>
-#include <klocale.h>
+#include <KLocale>
 
 #define SAGE_EXTENSION_CONSTRUCTORS(name) Sage##name##Extension::Sage##name##Extension(QObject* parent) : name##Extension(parent) {} \
                                      Sage##name##Extension::~Sage##name##Extension() {}
@@ -31,7 +31,7 @@ SAGE_EXTENSION_CONSTRUCTORS(History)
 
 QString SageHistoryExtension::lastResult()
 {
-    return "_";
+    return QLatin1String("_");
 }
 
 //Script Extension
@@ -39,7 +39,7 @@ SAGE_EXTENSION_CONSTRUCTORS(Script)
 
 QString SageScriptExtension::runExternalScript(const QString& path)
 {
-    return QString("execfile(\"%1\")").arg(path);
+    return QString::fromLatin1("execfile(\"%1\")").arg(path);
 }
 
 QString SageScriptExtension::scriptFileFilter()
@@ -50,7 +50,7 @@ QString SageScriptExtension::scriptFileFilter()
 
 QString SageScriptExtension::highlightingMode()
 {
-    return QString("python");
+    return QLatin1String("python");
 }
 
 //CAS extension
@@ -58,21 +58,21 @@ SAGE_EXTENSION_CONSTRUCTORS(CAS)
 
 QString SageCASExtension::solve(const QStringList& equations, const QStringList& variables)
 {
-    QString eqstr=QString("[%1]").arg(equations.join(","));
-    eqstr.replace('=', "=="); //Sage uses == for equations and = for assignments
-    QString variablestr=variables.join(",");
+    QString eqstr=QString::fromLatin1("[%1]").arg(equations.join(QLatin1String(",")));
+    eqstr.replace(QLatin1Char('='), QLatin1String("==")); //Sage uses == for equations and = for assignments
+    QString variablestr=variables.join(QLatin1String(","));
 
-    return QString("solve(%1,%2)").arg(eqstr, variablestr);
+    return QString::fromLatin1("solve(%1,%2)").arg(eqstr, variablestr);
 }
 
 QString SageCASExtension::simplify(const QString& expression)
 {
-    return QString("simplify(%1)").arg(expression);
+    return QString::fromLatin1("simplify(%1)").arg(expression);
 }
 
 QString SageCASExtension::expand(const QString& expression)
 {
-    return QString("expand(%1)").arg(expression);
+    return QString::fromLatin1("expand(%1)").arg(expression);
 }
 
 //Calculus Extension
@@ -80,22 +80,22 @@ SAGE_EXTENSION_CONSTRUCTORS(Calculus)
 
 QString SageCalculusExtension::limit(const QString& expression, const QString& variable, const QString& limit)
 {
-    return QString("limit(%1,%2=%3)").arg(expression, variable, limit);
+    return QString::fromLatin1("limit(%1,%2=%3)").arg(expression, variable, limit);
 }
 
 QString SageCalculusExtension::differentiate(const QString& function,const QString& variable, int times)
 {
-    return QString("diff(%1,%2,%3)").arg(function, variable, QString::number(times));
+    return QString::fromLatin1("diff(%1,%2,%3)").arg(function, variable, QString::number(times));
 }
 
 QString SageCalculusExtension::integrate(const QString& function, const QString& variable)
 {
-    return QString("integral(%1,%2)").arg(function, variable);
+    return QString::fromLatin1("integral(%1,%2)").arg(function, variable);
 }
 
 QString SageCalculusExtension::integrate(const QString& function,const QString& variable, const QString& left, const QString& right)
 {
-    return QString("integral(%1,%2,%3,%4)").arg(function, variable, left, right);
+    return QString::fromLatin1("integral(%1,%2,%3,%4)").arg(function, variable, left, right);
 }
 
 //Linear Algebra
@@ -103,77 +103,77 @@ SAGE_EXTENSION_CONSTRUCTORS(LinearAlgebra)
 
 QString SageLinearAlgebraExtension::createVector(const QStringList& entries, VectorType type)
 {
-    QString cmd="vector(";
+    QString cmd=QLatin1String("vector(");
     foreach(const QString& e, entries)
-        cmd+=e+',';
+        cmd+=e+QLatin1Char(',');
     cmd.chop(1);
-    cmd+=')';
+    cmd+=QLatin1Char(')');
 
     if(type==Cantor::LinearAlgebraExtension::ColumnVector)
-        cmd+=".transpose()";
+        cmd+=QLatin1String(".transpose()");
 
     return cmd;
 }
 
 QString SageLinearAlgebraExtension::nullVector(int size, VectorType type)
 {
-    QString cmd=QString("vector(seq(0 for i in range(0,%1)))").arg(size);
+    QString cmd=QString::fromLatin1("vector(seq(0 for i in range(0,%1)))").arg(size);
     if(type==Cantor::LinearAlgebraExtension::ColumnVector)
-        cmd+=".transpose()";
+        cmd+=QLatin1String(".transpose()");
 
     return cmd;
 }
 
 QString SageLinearAlgebraExtension::createMatrix(const Matrix& matrix)
 {
-    QString cmd="matrix([";
+    QString cmd=QLatin1String("matrix([");
     foreach(const QStringList& row, matrix)
     {
-        cmd+='[';
+        cmd+=QLatin1Char('[');
         foreach(const QString& entry, row)
-            cmd+=entry+',';
+            cmd+=entry+QLatin1Char(',');
         cmd.chop(1);
-        cmd+="],";
+        cmd+=QLatin1String("],");
     }
     cmd.chop(1);
-    cmd+="])";
+    cmd+=QLatin1String("])");
 
     return cmd;
 }
 
 QString SageLinearAlgebraExtension::identityMatrix(int size)
 {
-    return QString("identity_matrix(%1)").arg(size);
+    return QString::fromLatin1("identity_matrix(%1)").arg(size);
 }
 
 QString SageLinearAlgebraExtension::nullMatrix(int rows,int columns)
 {
-    return QString("null_matrix(%1,%2)").arg(rows, columns);
+    return QString::fromLatin1("null_matrix(%1,%2)").arg(rows, columns);
 }
 
 QString SageLinearAlgebraExtension::rank(const QString& matrix)
 {
-    return QString("%1.rank()").arg(matrix);
+    return QString::fromLatin1("%1.rank()").arg(matrix);
 }
 
 QString SageLinearAlgebraExtension::invertMatrix(const QString& matrix)
 {
-    return QString("%1.inverse()").arg(matrix);
+    return QString::fromLatin1("%1.inverse()").arg(matrix);
 }
 
 QString SageLinearAlgebraExtension::charPoly(const QString& matrix)
 {
-    return QString("%1.char_poly()").arg(matrix);
+    return QString::fromLatin1("%1.char_poly()").arg(matrix);
 }
 
 QString SageLinearAlgebraExtension::eigenVectors(const QString& matrix)
 {
-    return QString("%1.eigenvectors_right()").arg(matrix);
+    return QString::fromLatin1("%1.eigenvectors_right()").arg(matrix);
 }
 
 QString SageLinearAlgebraExtension::eigenValues(const QString& matrix)
 {
-    return QString("%1.eigenvalues()").arg(matrix);
+    return QString::fromLatin1("%1.eigenvalues()").arg(matrix);
 }
 
 //Plotting
@@ -181,14 +181,14 @@ SAGE_EXTENSION_CONSTRUCTORS(Plot)
 
 QString SagePlotExtension::plotFunction2d(const QString& function, const QString& variable, const QString& left, const QString& right)
 {
-    return QString("plot(%1,%2,%3,%4)").arg(function, variable, left, right);
+    return QString::fromLatin1("plot(%1,%2,%3,%4)").arg(function, variable, left, right);
 }
 
 QString SagePlotExtension::plotFunction3d(const QString& function, VariableParameter var1, VariableParameter var2)
 {
     const Interval& int1=var1.second;
     const Interval& int2=var2.second;
-    return QString("plot3d(%1,(%2,%3,%4),(%6,%7,%8))").arg(function,
+    return QString::fromLatin1("plot3d(%1,(%2,%3,%4),(%6,%7,%8))").arg(function,
                                                            var1.first, int1.first, int1.second,
                                                            var2.first, int2.first, int2.second);
 }
@@ -198,5 +198,5 @@ SAGE_EXTENSION_CONSTRUCTORS(Packaging)
 
 QString SagePackagingExtension::importPackage(const QString& module)
 {
-    return QString("import %1").arg(module);
+    return QString::fromLatin1("import %1").arg(module);
 }
